api

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 19, 2026 License: GPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// http holds HTTP endpoint binding configs.
	//
	// ID assigned by protobuf-global-extension-registry@google.com for
	// gRPC-Gateway project.
	//
	// optional gopencloud.gateway.ProtoEndpointBinding http = 1190;
	E_Http = &file_gopencloud_gateway_annotations_proto_extTypes[2]
	// openapi_operation holds OpenAPI method/operation options.
	//
	// optional gopencloud.gateway.openapi.Operation openapi_operation = 1191;
	E_OpenapiOperation = &file_gopencloud_gateway_annotations_proto_extTypes[3]
)

Extension fields to descriptorpb.MethodOptions.

var (
	// openapi_doc holds OpenAPI file options.
	//
	// optional gopencloud.gateway.openapi.Document openapi_doc = 1191;
	E_OpenapiDoc = &file_gopencloud_gateway_annotations_proto_extTypes[0]
)

Extension fields to descriptorpb.FileOptions.

var (
	// optional gopencloud.gateway.openapi.Schema openapi_enum = 1191;
	E_OpenapiEnum = &file_gopencloud_gateway_annotations_proto_extTypes[5]
)

Extension fields to descriptorpb.EnumOptions.

var (
	// optional gopencloud.gateway.openapi.Schema openapi_field = 1191;
	E_OpenapiField = &file_gopencloud_gateway_annotations_proto_extTypes[6]
)

Extension fields to descriptorpb.FieldOptions.

var (
	// optional gopencloud.gateway.openapi.Schema openapi_schema = 1191;
	E_OpenapiSchema = &file_gopencloud_gateway_annotations_proto_extTypes[4]
)

Extension fields to descriptorpb.MessageOptions.

var (
	// openapi_service_doc holds OpenAPI file options.
	//
	// optional gopencloud.gateway.openapi.Document openapi_service_doc = 1191;
	E_OpenapiServiceDoc = &file_gopencloud_gateway_annotations_proto_extTypes[1]
)

Extension fields to descriptorpb.ServiceOptions.

var File_gopencloud_gateway_annotations_proto protoreflect.FileDescriptor
var File_gopencloud_gateway_config_proto protoreflect.FileDescriptor
var File_gopencloud_gateway_gateway_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type AdditionalEndpointBinding

type AdditionalEndpointBinding struct {

	// pattern specifies the HTTP method for this additional endpoint binding.
	//
	// Types that are valid to be assigned to Pattern:
	//
	//	*AdditionalEndpointBinding_Get
	//	*AdditionalEndpointBinding_Put
	//	*AdditionalEndpointBinding_Post
	//	*AdditionalEndpointBinding_Delete
	//	*AdditionalEndpointBinding_Patch
	//	*AdditionalEndpointBinding_Custom
	Pattern isAdditionalEndpointBinding_Pattern `protobuf_oneof:"pattern"`
	// body is a request message field selector that will be read via HTTP body.
	//
	// '*' indicates that the entire request message gets decoded from the body.
	// An empty string indicates that no part of the request gets decoded from the
	// body.
	//
	// NOTE: Not all methods support HTTP body.
	Body *string `protobuf:"bytes,8,opt,name=body" json:"body,omitempty"`
	// response_body is a response message field selector that will be written to
	// HTTP response.
	//
	// '*' or an empty string indicates that the entire response message gets
	// encoded.
	ResponseBody *string `protobuf:"bytes,9,opt,name=response_body,json=responseBody" json:"response_body,omitempty"`
	// query_params are explicit query parameter bindings that can be used to
	// rename or ignore query parameters.
	QueryParams []*QueryParameterBinding `protobuf:"bytes,10,rep,name=query_params,json=queryParams" json:"query_params,omitempty"`
	// disable_query_param_discovery can be used to avoid auto binding query
	// parameters.
	DisableQueryParamDiscovery *bool `` /* 138-byte string literal not displayed */
	// stream holds configurations for streaming methods.
	Stream *StreamConfig `protobuf:"bytes,12,opt,name=stream" json:"stream,omitempty"`
	// contains filtered or unexported fields
}

AdditionalEndpointBinding is an additional gRPC method - HTTP endpoint binding specification.

func (*AdditionalEndpointBinding) Descriptor deprecated

func (*AdditionalEndpointBinding) Descriptor() ([]byte, []int)

Deprecated: Use AdditionalEndpointBinding.ProtoReflect.Descriptor instead.

func (*AdditionalEndpointBinding) GetBody

func (x *AdditionalEndpointBinding) GetBody() string

func (*AdditionalEndpointBinding) GetCustom

func (x *AdditionalEndpointBinding) GetCustom() *CustomPattern

func (*AdditionalEndpointBinding) GetDelete

func (x *AdditionalEndpointBinding) GetDelete() string

func (*AdditionalEndpointBinding) GetDisableQueryParamDiscovery

func (x *AdditionalEndpointBinding) GetDisableQueryParamDiscovery() bool

func (*AdditionalEndpointBinding) GetGet

func (x *AdditionalEndpointBinding) GetGet() string

func (*AdditionalEndpointBinding) GetPatch

func (x *AdditionalEndpointBinding) GetPatch() string

func (*AdditionalEndpointBinding) GetPattern

func (x *AdditionalEndpointBinding) GetPattern() isAdditionalEndpointBinding_Pattern

func (*AdditionalEndpointBinding) GetPost

func (x *AdditionalEndpointBinding) GetPost() string

func (*AdditionalEndpointBinding) GetPut

func (x *AdditionalEndpointBinding) GetPut() string

func (*AdditionalEndpointBinding) GetQueryParams

func (x *AdditionalEndpointBinding) GetQueryParams() []*QueryParameterBinding

func (*AdditionalEndpointBinding) GetResponseBody

func (x *AdditionalEndpointBinding) GetResponseBody() string

func (*AdditionalEndpointBinding) GetStream

func (x *AdditionalEndpointBinding) GetStream() *StreamConfig

func (*AdditionalEndpointBinding) ProtoMessage

func (*AdditionalEndpointBinding) ProtoMessage()

func (*AdditionalEndpointBinding) ProtoReflect

func (*AdditionalEndpointBinding) Reset

func (x *AdditionalEndpointBinding) Reset()

func (*AdditionalEndpointBinding) String

func (x *AdditionalEndpointBinding) String() string

type AdditionalEndpointBinding_Custom

type AdditionalEndpointBinding_Custom struct {
	// custom can be used for custom HTTP methods.
	//
	// Not all HTTP methods are supported in OpenAPI specification, however and
	// will not be included in the generated OpenAPI document.
	Custom *CustomPattern `protobuf:"bytes,7,opt,name=custom,oneof"`
}

type AdditionalEndpointBinding_Delete

type AdditionalEndpointBinding_Delete struct {
	Delete string `protobuf:"bytes,5,opt,name=delete,oneof"`
}

type AdditionalEndpointBinding_Get

type AdditionalEndpointBinding_Get struct {
	Get string `protobuf:"bytes,2,opt,name=get,oneof"`
}

type AdditionalEndpointBinding_Patch

type AdditionalEndpointBinding_Patch struct {
	Patch string `protobuf:"bytes,6,opt,name=patch,oneof"`
}

type AdditionalEndpointBinding_Post

type AdditionalEndpointBinding_Post struct {
	Post string `protobuf:"bytes,4,opt,name=post,oneof"`
}

type AdditionalEndpointBinding_Put

type AdditionalEndpointBinding_Put struct {
	Put string `protobuf:"bytes,3,opt,name=put,oneof"`
}

type Config

type Config struct {

	// gateway holds gateway configs.
	Gateway *GatewaySpec `protobuf:"bytes,1,opt,name=gateway" json:"gateway,omitempty"`
	// openapi holds OpenAPI v3.1 configs.
	Openapi *OpenAPISpec `protobuf:"bytes,2,opt,name=openapi" json:"openapi,omitempty"`
	// contains filtered or unexported fields
}

Config is the content of a configuration file.

func (*Config) Descriptor deprecated

func (*Config) Descriptor() ([]byte, []int)

Deprecated: Use Config.ProtoReflect.Descriptor instead.

func (*Config) GetGateway

func (x *Config) GetGateway() *GatewaySpec

func (*Config) GetOpenapi

func (x *Config) GetOpenapi() *OpenAPISpec

func (*Config) ProtoMessage

func (*Config) ProtoMessage()

func (*Config) ProtoReflect

func (x *Config) ProtoReflect() protoreflect.Message

func (*Config) Reset

func (x *Config) Reset()

func (*Config) String

func (x *Config) String() string

type CustomPattern

type CustomPattern struct {

	// method is the custom HTTP method.
	Method *string `protobuf:"bytes,1,opt,name=method" json:"method,omitempty"`
	// path is the HTTP path pattern.
	Path *string `protobuf:"bytes,2,opt,name=path" json:"path,omitempty"`
	// contains filtered or unexported fields
}

CustomPattern describes an HTTP pattern and custom method.

func (*CustomPattern) Descriptor deprecated

func (*CustomPattern) Descriptor() ([]byte, []int)

Deprecated: Use CustomPattern.ProtoReflect.Descriptor instead.

func (*CustomPattern) GetMethod

func (x *CustomPattern) GetMethod() string

func (*CustomPattern) GetPath

func (x *CustomPattern) GetPath() string

func (*CustomPattern) ProtoMessage

func (*CustomPattern) ProtoMessage()

func (*CustomPattern) ProtoReflect

func (x *CustomPattern) ProtoReflect() protoreflect.Message

func (*CustomPattern) Reset

func (x *CustomPattern) Reset()

func (*CustomPattern) String

func (x *CustomPattern) String() string

type EndpointBinding

type EndpointBinding struct {

	// selector is a dot-separated gRPC service method selector.
	//
	// If the selector begins with `~.`, the current proto package will be added
	// to the beginning of the path. For instance: `~.MyService`. Since no proto
	// package can be deduced in the global config file, this alias cannot be used
	// in the global config file.
	//
	// If the selector does not begin with `~.`, it will be treated as a fully
	// qualified method name (FQMN).
	//
	// NOTE: In proto annotations, this field gets automatically assigned, thus it
	// is only applicable in configuration files.
	Selector *string `protobuf:"bytes,1,opt,name=selector" json:"selector,omitempty"`
	// pattern specifies the HTTP method for this endpoint binding.
	//
	// Types that are valid to be assigned to Pattern:
	//
	//	*EndpointBinding_Get
	//	*EndpointBinding_Put
	//	*EndpointBinding_Post
	//	*EndpointBinding_Delete
	//	*EndpointBinding_Patch
	//	*EndpointBinding_Custom
	Pattern isEndpointBinding_Pattern `protobuf_oneof:"pattern"`
	// body is a request message field selector that will be read via HTTP body.
	//
	// `*` indicates that the entire request message gets decoded from the body.
	// An empty string (default value) indicates that no part of the request gets
	// decoded from the body.
	//
	// NOTE: Not all methods support HTTP body.
	Body *string `protobuf:"bytes,8,opt,name=body" json:"body,omitempty"`
	// response_body is a response message field selector that will be written to
	// HTTP response.
	//
	// `*` or an empty string indicates that the entire response message gets
	// encoded.
	ResponseBody *string `protobuf:"bytes,9,opt,name=response_body,json=responseBody" json:"response_body,omitempty"`
	// query_params are explicit query parameter bindings that can be used to
	// rename or ignore query parameters.
	QueryParams []*QueryParameterBinding `protobuf:"bytes,10,rep,name=query_params,json=queryParams" json:"query_params,omitempty"`
	// additional_bindings holds additional bindings for the same gRPC service
	// method.
	AdditionalBindings []*AdditionalEndpointBinding `protobuf:"bytes,11,rep,name=additional_bindings,json=additionalBindings" json:"additional_bindings,omitempty"`
	// disable_query_param_discovery can be used to avoid auto binding query
	// parameters.
	//
	// Default: `false`
	DisableQueryParamDiscovery *bool `` /* 138-byte string literal not displayed */
	// stream holds configurations for streaming methods.
	Stream *StreamConfig `protobuf:"bytes,13,opt,name=stream" json:"stream,omitempty"`
	// aliases are additional routes for this endpoint binding.
	//
	// This field translates to additional_bindings, inheriting all values from
	// endpoint binding. Consider this a syntax sugar for additional_bindings. If
	// additional binding with same route and method exists, alias will not work.
	Aliases []string `protobuf:"bytes,14,rep,name=aliases" json:"aliases,omitempty"`
	// contains filtered or unexported fields
}

EndpointBinding represents an HTTP endpoint(s) to gRPC method binding.

func (*EndpointBinding) Descriptor deprecated

func (*EndpointBinding) Descriptor() ([]byte, []int)

Deprecated: Use EndpointBinding.ProtoReflect.Descriptor instead.

func (*EndpointBinding) GetAdditionalBindings

func (x *EndpointBinding) GetAdditionalBindings() []*AdditionalEndpointBinding

func (*EndpointBinding) GetAliases

func (x *EndpointBinding) GetAliases() []string

func (*EndpointBinding) GetBody

func (x *EndpointBinding) GetBody() string

func (*EndpointBinding) GetCustom

func (x *EndpointBinding) GetCustom() *CustomPattern

func (*EndpointBinding) GetDelete

func (x *EndpointBinding) GetDelete() string

func (*EndpointBinding) GetDisableQueryParamDiscovery

func (x *EndpointBinding) GetDisableQueryParamDiscovery() bool

func (*EndpointBinding) GetGet

func (x *EndpointBinding) GetGet() string

func (*EndpointBinding) GetPatch

func (x *EndpointBinding) GetPatch() string

func (*EndpointBinding) GetPattern

func (x *EndpointBinding) GetPattern() isEndpointBinding_Pattern

func (*EndpointBinding) GetPost

func (x *EndpointBinding) GetPost() string

func (*EndpointBinding) GetPut

func (x *EndpointBinding) GetPut() string

func (*EndpointBinding) GetQueryParams

func (x *EndpointBinding) GetQueryParams() []*QueryParameterBinding

func (*EndpointBinding) GetResponseBody

func (x *EndpointBinding) GetResponseBody() string

func (*EndpointBinding) GetSelector

func (x *EndpointBinding) GetSelector() string

func (*EndpointBinding) GetStream

func (x *EndpointBinding) GetStream() *StreamConfig

func (*EndpointBinding) ProtoMessage

func (*EndpointBinding) ProtoMessage()

func (*EndpointBinding) ProtoReflect

func (x *EndpointBinding) ProtoReflect() protoreflect.Message

func (*EndpointBinding) Reset

func (x *EndpointBinding) Reset()

func (*EndpointBinding) String

func (x *EndpointBinding) String() string

type EndpointBinding_Custom

type EndpointBinding_Custom struct {
	// custom can be used for custom HTTP methods.
	//
	// Not all HTTP methods are supported in OpenAPI specification and will not
	// be included in the generated OpenAPI document.
	Custom *CustomPattern `protobuf:"bytes,7,opt,name=custom,oneof"`
}

type EndpointBinding_Delete

type EndpointBinding_Delete struct {
	// delete defines route for a DELETE HTTP endpoint.
	Delete string `protobuf:"bytes,5,opt,name=delete,oneof"`
}

type EndpointBinding_Get

type EndpointBinding_Get struct {
	// get defines route for a GET HTTP endpoint.
	Get string `protobuf:"bytes,2,opt,name=get,oneof"`
}

type EndpointBinding_Patch

type EndpointBinding_Patch struct {
	// patch defines route for a PATCH HTTP endpoint.
	Patch string `protobuf:"bytes,6,opt,name=patch,oneof"`
}

type EndpointBinding_Post

type EndpointBinding_Post struct {
	// post defines route for a POST HTTP endpoint.
	Post string `protobuf:"bytes,4,opt,name=post,oneof"`
}

type EndpointBinding_Put

type EndpointBinding_Put struct {
	// put defines route for a PUT HTTP endpoint.
	Put string `protobuf:"bytes,3,opt,name=put,oneof"`
}

type GatewaySpec

type GatewaySpec struct {

	// endpoints hold a series of endpoint binding specs.
	Endpoints []*EndpointBinding `protobuf:"bytes,1,rep,name=endpoints" json:"endpoints,omitempty"`
	// contains filtered or unexported fields
}

GatewaySpec holds gRPC gateway configurations.

func (*GatewaySpec) Descriptor deprecated

func (*GatewaySpec) Descriptor() ([]byte, []int)

Deprecated: Use GatewaySpec.ProtoReflect.Descriptor instead.

func (*GatewaySpec) GetEndpoints

func (x *GatewaySpec) GetEndpoints() []*EndpointBinding

func (*GatewaySpec) ProtoMessage

func (*GatewaySpec) ProtoMessage()

func (*GatewaySpec) ProtoReflect

func (x *GatewaySpec) ProtoReflect() protoreflect.Message

func (*GatewaySpec) Reset

func (x *GatewaySpec) Reset()

func (*GatewaySpec) String

func (x *GatewaySpec) String() string

type OpenAPIEnumSpec

type OpenAPIEnumSpec struct {

	// selector is a dot-separated protobuf enum selector.
	//
	// If the selector begins with a '.', it will be treated as an absolute path.
	// If it begins with '~.', the current proto package will be added to the
	// beginning of the path. For instance: `~.MyEnum`. Since no proto package can
	// be deduced in the global config file, this alias cannot be used in the
	// global config file. If the path does not begin with a '.' or '~.', it will
	// be treated as a relative path and a search from the current proto package
	// will be performed in order to find the enum.
	Selector *string `protobuf:"bytes,1,opt,name=selector" json:"selector,omitempty"`
	// schema controls the OpenAPI v3.1 schema generation for this proto enum.
	Schema *openapi.Schema `protobuf:"bytes,2,opt,name=schema" json:"schema,omitempty"`
	// contains filtered or unexported fields
}

OpenAPIEnumSpec defines configuration for generating OpenAPI documentation for protobuf enums.

func (*OpenAPIEnumSpec) Descriptor deprecated

func (*OpenAPIEnumSpec) Descriptor() ([]byte, []int)

Deprecated: Use OpenAPIEnumSpec.ProtoReflect.Descriptor instead.

func (*OpenAPIEnumSpec) GetSchema

func (x *OpenAPIEnumSpec) GetSchema() *openapi.Schema

func (*OpenAPIEnumSpec) GetSelector

func (x *OpenAPIEnumSpec) GetSelector() string

func (*OpenAPIEnumSpec) ProtoMessage

func (*OpenAPIEnumSpec) ProtoMessage()

func (*OpenAPIEnumSpec) ProtoReflect

func (x *OpenAPIEnumSpec) ProtoReflect() protoreflect.Message

func (*OpenAPIEnumSpec) Reset

func (x *OpenAPIEnumSpec) Reset()

func (*OpenAPIEnumSpec) String

func (x *OpenAPIEnumSpec) String() string

type OpenAPIMessageSpec

type OpenAPIMessageSpec struct {

	// selector is a dot-separated protobuf message selector.
	//
	// If the selector begins with a '.', it will be treated as an absolute path.
	// If it begins with '~.', the current proto package will be added to the
	// beginning of the path. For instance: `~.MyMessage`. Since no proto package
	// can be deduced in the global config file, this alias cannot be used in the
	// global config file. If the path does not begin with a '.' or '~.', it will
	// be treated as a relative path and a search from the current proto package
	// will be performed in order to find the message.
	Selector *string `protobuf:"bytes,1,opt,name=selector" json:"selector,omitempty"`
	// schema controls the OpenAPI v3.1 schema generation for this proto message.
	Schema *openapi.Schema `protobuf:"bytes,2,opt,name=schema" json:"schema,omitempty"`
	// fields allows controlling the OpenAPI v3.1 generation for individual fields
	// in this proto message.
	Fields map[string]*openapi.Schema `` /* 132-byte string literal not displayed */
	// contains filtered or unexported fields
}

OpenAPIMessageSpec defines configuration for generating OpenAPI documentation for protobuf messages.

func (*OpenAPIMessageSpec) Descriptor deprecated

func (*OpenAPIMessageSpec) Descriptor() ([]byte, []int)

Deprecated: Use OpenAPIMessageSpec.ProtoReflect.Descriptor instead.

func (*OpenAPIMessageSpec) GetFields

func (x *OpenAPIMessageSpec) GetFields() map[string]*openapi.Schema

func (*OpenAPIMessageSpec) GetSchema

func (x *OpenAPIMessageSpec) GetSchema() *openapi.Schema

func (*OpenAPIMessageSpec) GetSelector

func (x *OpenAPIMessageSpec) GetSelector() string

func (*OpenAPIMessageSpec) ProtoMessage

func (*OpenAPIMessageSpec) ProtoMessage()

func (*OpenAPIMessageSpec) ProtoReflect

func (x *OpenAPIMessageSpec) ProtoReflect() protoreflect.Message

func (*OpenAPIMessageSpec) Reset

func (x *OpenAPIMessageSpec) Reset()

func (*OpenAPIMessageSpec) String

func (x *OpenAPIMessageSpec) String() string

type OpenAPIServiceSpec

type OpenAPIServiceSpec struct {

	// selector is a dot-separated gRPC service method selector.
	//
	// If the selector begins with '~.', the current proto package will be added
	// to the beginning of the path. For instance: `~.MyService`. Since no proto
	// package can be deduced in the global config file, this alias cannot be used
	// in the global config file.
	//
	// If the selector does not begin with '~.', it will be treated as a fully
	// qualified method name (FQMN).
	Selector *string `protobuf:"bytes,1,opt,name=selector" json:"selector,omitempty"`
	// document can be used to override default values for OpenAPI document files
	// when using the option to generate OpenAPI files per service.
	//
	// Additionally, this can be used to change documentation generation behavior
	// such as default responses regardless of the output generation mode.
	//
	// NOTE: This document will only be used when using output mode of "service"
	// and in all other modes, this object simply gets ignored save for the config
	// field. Since the config field instructs the generation of responses and the
	// document objects for that service only, regardless of the output mode the
	// settings will be honored.
	Document *openapi.Document `protobuf:"bytes,2,opt,name=document" json:"document,omitempty"`
	// methods maps each method to an operation configuration.
	Methods map[string]*openapi.Operation `` /* 134-byte string literal not displayed */
	// contains filtered or unexported fields
}

OpenAPIServiceSpec defines configuration for generating OpenAPI documentation for gRPC services.

func (*OpenAPIServiceSpec) Descriptor deprecated

func (*OpenAPIServiceSpec) Descriptor() ([]byte, []int)

Deprecated: Use OpenAPIServiceSpec.ProtoReflect.Descriptor instead.

func (*OpenAPIServiceSpec) GetDocument

func (x *OpenAPIServiceSpec) GetDocument() *openapi.Document

func (*OpenAPIServiceSpec) GetMethods

func (x *OpenAPIServiceSpec) GetMethods() map[string]*openapi.Operation

func (*OpenAPIServiceSpec) GetSelector

func (x *OpenAPIServiceSpec) GetSelector() string

func (*OpenAPIServiceSpec) ProtoMessage

func (*OpenAPIServiceSpec) ProtoMessage()

func (*OpenAPIServiceSpec) ProtoReflect

func (x *OpenAPIServiceSpec) ProtoReflect() protoreflect.Message

func (*OpenAPIServiceSpec) Reset

func (x *OpenAPIServiceSpec) Reset()

func (*OpenAPIServiceSpec) String

func (x *OpenAPIServiceSpec) String() string

type OpenAPISpec

type OpenAPISpec struct {

	// Document is the OpenAPI v3.1 document configuration which controls how the
	// OpenAPI documentation is generated.
	//
	// This document can be defined to define a base config for all documents (if
	// in the global config) or the document for the current output target. For
	// instance, when using output mode of "service", each service defined in the
	// associated proto file inherits this base document and can additionally
	// specify more defaults for its own OpenAPI document. When defining this in
	// the global config and for specific proto files, the configs get merged
	// together but the priority is given to the proto document.
	Document *openapi.Document `protobuf:"bytes,1,opt,name=document" json:"document,omitempty"`
	// services is used to configure OpenAPI v3.1 output for gRPC services.
	Services []*OpenAPIServiceSpec `protobuf:"bytes,2,rep,name=services" json:"services,omitempty"`
	// messages is used to configure OpenAPI v3.1 output for protobuf messages.
	Messages []*OpenAPIMessageSpec `protobuf:"bytes,3,rep,name=messages" json:"messages,omitempty"`
	// enums is used to configure OpenAPI v3.1 output for protobuf enums.
	Enums []*OpenAPIEnumSpec `protobuf:"bytes,4,rep,name=enums" json:"enums,omitempty"`
	// contains filtered or unexported fields
}

OpenAPISpec defines the overall OpenAPI documentation configuration.

func (*OpenAPISpec) Descriptor deprecated

func (*OpenAPISpec) Descriptor() ([]byte, []int)

Deprecated: Use OpenAPISpec.ProtoReflect.Descriptor instead.

func (*OpenAPISpec) GetDocument

func (x *OpenAPISpec) GetDocument() *openapi.Document

func (*OpenAPISpec) GetEnums

func (x *OpenAPISpec) GetEnums() []*OpenAPIEnumSpec

func (*OpenAPISpec) GetMessages

func (x *OpenAPISpec) GetMessages() []*OpenAPIMessageSpec

func (*OpenAPISpec) GetServices

func (x *OpenAPISpec) GetServices() []*OpenAPIServiceSpec

func (*OpenAPISpec) ProtoMessage

func (*OpenAPISpec) ProtoMessage()

func (*OpenAPISpec) ProtoReflect

func (x *OpenAPISpec) ProtoReflect() protoreflect.Message

func (*OpenAPISpec) Reset

func (x *OpenAPISpec) Reset()

func (*OpenAPISpec) String

func (x *OpenAPISpec) String() string

type ProtoEndpointBinding

type ProtoEndpointBinding struct {

	// Types that are valid to be assigned to Pattern:
	//
	//	*ProtoEndpointBinding_Get
	//	*ProtoEndpointBinding_Put
	//	*ProtoEndpointBinding_Post
	//	*ProtoEndpointBinding_Delete
	//	*ProtoEndpointBinding_Patch
	//	*ProtoEndpointBinding_Custom
	Pattern                    isProtoEndpointBinding_Pattern `protobuf_oneof:"pattern"`
	Body                       *string                        `protobuf:"bytes,8,opt,name=body" json:"body,omitempty"`
	QueryParams                []*QueryParameterBinding       `protobuf:"bytes,9,rep,name=query_params,json=queryParams" json:"query_params,omitempty"`
	AdditionalBindings         []*AdditionalEndpointBinding   `protobuf:"bytes,10,rep,name=additional_bindings,json=additionalBindings" json:"additional_bindings,omitempty"`
	DisableQueryParamDiscovery *bool                          `` /* 138-byte string literal not displayed */
	Stream                     *StreamConfig                  `protobuf:"bytes,12,opt,name=stream" json:"stream,omitempty"`
	// aliases are additional routes for this endpoint binding.
	//
	// This field translates to additional_bindings, inheriting all values from
	// endpoint binding. Consider this a syntax sugar for additional_bindings. If
	// additional binding with same route and method exists, alias will not work.
	Aliases []string `protobuf:"bytes,13,rep,name=aliases" json:"aliases,omitempty"`
	// contains filtered or unexported fields
}

func (*ProtoEndpointBinding) Descriptor deprecated

func (*ProtoEndpointBinding) Descriptor() ([]byte, []int)

Deprecated: Use ProtoEndpointBinding.ProtoReflect.Descriptor instead.

func (*ProtoEndpointBinding) GetAdditionalBindings

func (x *ProtoEndpointBinding) GetAdditionalBindings() []*AdditionalEndpointBinding

func (*ProtoEndpointBinding) GetAliases

func (x *ProtoEndpointBinding) GetAliases() []string

func (*ProtoEndpointBinding) GetBody

func (x *ProtoEndpointBinding) GetBody() string

func (*ProtoEndpointBinding) GetCustom

func (x *ProtoEndpointBinding) GetCustom() *CustomPattern

func (*ProtoEndpointBinding) GetDelete

func (x *ProtoEndpointBinding) GetDelete() string

func (*ProtoEndpointBinding) GetDisableQueryParamDiscovery

func (x *ProtoEndpointBinding) GetDisableQueryParamDiscovery() bool

func (*ProtoEndpointBinding) GetGet

func (x *ProtoEndpointBinding) GetGet() string

func (*ProtoEndpointBinding) GetPatch

func (x *ProtoEndpointBinding) GetPatch() string

func (*ProtoEndpointBinding) GetPattern

func (x *ProtoEndpointBinding) GetPattern() isProtoEndpointBinding_Pattern

func (*ProtoEndpointBinding) GetPost

func (x *ProtoEndpointBinding) GetPost() string

func (*ProtoEndpointBinding) GetPut

func (x *ProtoEndpointBinding) GetPut() string

func (*ProtoEndpointBinding) GetQueryParams

func (x *ProtoEndpointBinding) GetQueryParams() []*QueryParameterBinding

func (*ProtoEndpointBinding) GetStream

func (x *ProtoEndpointBinding) GetStream() *StreamConfig

func (*ProtoEndpointBinding) ProtoMessage

func (*ProtoEndpointBinding) ProtoMessage()

func (*ProtoEndpointBinding) ProtoReflect

func (x *ProtoEndpointBinding) ProtoReflect() protoreflect.Message

func (*ProtoEndpointBinding) Reset

func (x *ProtoEndpointBinding) Reset()

func (*ProtoEndpointBinding) String

func (x *ProtoEndpointBinding) String() string

type ProtoEndpointBinding_Custom

type ProtoEndpointBinding_Custom struct {
	// custom can be used for custom HTTP methods.
	Custom *CustomPattern `protobuf:"bytes,7,opt,name=custom,oneof"`
}

type ProtoEndpointBinding_Delete

type ProtoEndpointBinding_Delete struct {
	Delete string `protobuf:"bytes,5,opt,name=delete,oneof"`
}

type ProtoEndpointBinding_Get

type ProtoEndpointBinding_Get struct {
	Get string `protobuf:"bytes,2,opt,name=get,oneof"`
}

type ProtoEndpointBinding_Patch

type ProtoEndpointBinding_Patch struct {
	Patch string `protobuf:"bytes,6,opt,name=patch,oneof"`
}

type ProtoEndpointBinding_Post

type ProtoEndpointBinding_Post struct {
	Post string `protobuf:"bytes,4,opt,name=post,oneof"`
}

type ProtoEndpointBinding_Put

type ProtoEndpointBinding_Put struct {
	Put string `protobuf:"bytes,3,opt,name=put,oneof"`
}

type QueryParameterBinding

type QueryParameterBinding struct {

	// selector is a dot-separated path to the request message's field.
	Selector *string `protobuf:"bytes,1,opt,name=selector" json:"selector,omitempty"`
	// name is the name of the HTTP query parameter that will be used.
	Name *string `protobuf:"bytes,2,opt,name=name" json:"name,omitempty"`
	// ignore avoids reading this query parameter altogether (default: false).
	Ignore *bool `protobuf:"varint,3,opt,name=ignore" json:"ignore,omitempty"`
	// contains filtered or unexported fields
}

QueryParameterBinding describes a query parameter to request message binding.

func (*QueryParameterBinding) Descriptor deprecated

func (*QueryParameterBinding) Descriptor() ([]byte, []int)

Deprecated: Use QueryParameterBinding.ProtoReflect.Descriptor instead.

func (*QueryParameterBinding) GetIgnore

func (x *QueryParameterBinding) GetIgnore() bool

func (*QueryParameterBinding) GetName

func (x *QueryParameterBinding) GetName() string

func (*QueryParameterBinding) GetSelector

func (x *QueryParameterBinding) GetSelector() string

func (*QueryParameterBinding) ProtoMessage

func (*QueryParameterBinding) ProtoMessage()

func (*QueryParameterBinding) ProtoReflect

func (x *QueryParameterBinding) ProtoReflect() protoreflect.Message

func (*QueryParameterBinding) Reset

func (x *QueryParameterBinding) Reset()

func (*QueryParameterBinding) String

func (x *QueryParameterBinding) String() string

type StreamConfig

type StreamConfig struct {

	// disable_websockets indicates whether or not websockets are allowed for this
	// method. The client must still ask for a connection upgrade.
	DisableWebsockets *bool `protobuf:"varint,1,opt,name=disable_websockets,json=disableWebsockets" json:"disable_websockets,omitempty"`
	// disable_sse indicates whether or not server-sent events are allowed.
	//
	// see:
	// https://developer.mozilla.org/en-US/docs/Web/API/Server-sent_events/Using_server-sent_events
	//
	// SSE is only used when Accept-Type from the request includes MIME type
	// text/event-stream.
	DisableSse *bool `protobuf:"varint,2,opt,name=disable_sse,json=disableSse" json:"disable_sse,omitempty"`
	// disable_chunked indicates whether or not chunked transfer encoding is
	// allowed.
	//
	// NOTE: Chunked transfer encoding is disabled in HTTP/2 so this option will
	// only be available if the request is HTTP/1.
	DisableChunkedTransfer *bool `protobuf:"varint,3,opt,name=disable_chunked_transfer,json=disableChunkedTransfer" json:"disable_chunked_transfer,omitempty"`
	// contains filtered or unexported fields
}

StreamConfig sets the behavior of the HTTP server for gRPC streaming methods.

func (*StreamConfig) Descriptor deprecated

func (*StreamConfig) Descriptor() ([]byte, []int)

Deprecated: Use StreamConfig.ProtoReflect.Descriptor instead.

func (*StreamConfig) GetDisableChunkedTransfer

func (x *StreamConfig) GetDisableChunkedTransfer() bool

func (*StreamConfig) GetDisableSse

func (x *StreamConfig) GetDisableSse() bool

func (*StreamConfig) GetDisableWebsockets

func (x *StreamConfig) GetDisableWebsockets() bool

func (*StreamConfig) ProtoMessage

func (*StreamConfig) ProtoMessage()

func (*StreamConfig) ProtoReflect

func (x *StreamConfig) ProtoReflect() protoreflect.Message

func (*StreamConfig) Reset

func (x *StreamConfig) Reset()

func (*StreamConfig) String

func (x *StreamConfig) String() string

Directories

Path Synopsis

Jump to